"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _getSonarProperties = require("./getSonarProperties");
var _getFileUtils = require("../eslint/getFileUtils");
var _fileUtils = require("../../utils/fileUtils");
var _requestUtils = require("../../utils/requestUtils");
var _grfanaAPI = require("../../grafana/grfanaAPI");
/**
 * @note javascript code  to start sonar Server
 */

/**
 * @function executeSonarAnalysis - start sonar analysis and send metric to sonar server
 * @param {Object} cliParams - Object represent cli Argument
 */

function executeSonarAnalysis(cliParams) {
  var {
    env,
    cmdExecuted
  } = cliParams;
  _logger.Logger.createLogFile();
  const command = (0, _getSonarProperties.getSonarProperties)(cliParams);
  const child_process = (0, _child_process.spawn)("java", command);
  _logger.Logger.cliLog("success", "\n Sending report to SonarQube ...");
  child_process.stdout.on("data", data => {
    _logger.Logger.log(_logger.Logger.INFO_TYPE, data.toString());
    _logger.Logger.emit(data);
  });
  child_process.stderr.on("data", errorOut => {
    // error will appear here
    // Logger.error(Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", error => {
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, "\n failed to send report to sonarQube ...");
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, `Error: ${error.message}`);
  });
  child_process.on("close", code => {
    var {
      branchDiffPath
    } = (0, _fileUtils.getLintConfiguration)();
    if (code === 0) {
      global.analytics.sonarQubeStatus = true;
    }
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    const analysisStatus = code === 0 ? "success" : "failed";
    const reportStatus = code === 0 ? "successfully" : "failed";
    const overallStatus = code === 0 ? "Success" : "Failure";
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, `\n SonarQube analysis ${analysisStatus} ...`);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, `\n Report ${reportStatus} sent to the server :  Status - ${overallStatus}`);
    _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `\n JSON report Path - ${(0, _getFileUtils.getLintReportPath)()}`);
    if (code === 0) {
      _logger.Logger.cliLog(_logger.Logger.PATH_TYPE, `\n Report URL - ${(0, _sonarReportSummary.getSummaryOfLint)(cliParams).web_url}`);
      _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `\n SonarQube Artifacts Path - ${(0, _getSonarProperties.getSonarArtifactsDir)()}`);
    }
    // env == "ci" && cmdExecuted  == "lint-ci"  && (global.analytics.totalIssues > 0 || code == 1) &&  pushInfoToGrafana(cliParams)
    const ciCommands = ["lint-ci", "dev-ci", "exemption-report"];
    const shouldRemoveFiles = env == "ci" && ciCommands.includes(cliParams.cmdExecuted);
    if (shouldRemoveFiles) {
      (0, _getFileUtils.removeFile)(branchDiffPath);
      (0, _getFileUtils.removeFile)((0, _requestUtils.getExemptionFileInfoPath)());
    }
  });
}