"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pushInfoToGrafana = pushInfoToGrafana;
const {
  apiEndPoint,
  path,
  requestHostDomain,
  auth_token_noExpired,
  type,
  metricName,
  metricType,
  metricValue,
  sleepTime
} = require("./grafana-config");
const {
  requestAPI
} = require("../utils/requestUtils");
const {
  Logger
} = require("../utils/logger");
const {
  getProjectName
} = require("../core/sonar-dependencies/getSonarProperties");

/**
 * @function constructLayoutInfo
 * @description - construct layout info
 * @param {Array<string>} cliArgs 
 * @returns {Object of grafana layout info}
 */
async function constructLayoutInfo(cliArgs) {
  var _ticketDetails$contac, _global;
  const {
    developerName,
    ticketId,
    token
  } = cliArgs;
  const ticketDetails = JSON.parse(await getModuleName(ticketId, token));
  return {
    "ModuleName": (ticketDetails === null || ticketDetails === void 0 || (_ticketDetails$contac = ticketDetails.contact) === null || _ticketDetails$contac === void 0 || (_ticketDetails$contac = _ticketDetails$contac.account) === null || _ticketDetails$contac === void 0 ? void 0 : _ticketDetails$contac.accountName) || "Desk",
    "Project_Name": getProjectName(cliArgs),
    "Ticket_Id": ticketId,
    "DeveloperEmail": developerName,
    "isExemptionApplied": ((_global = global) === null || _global === void 0 || (_global = _global.analytics) === null || _global === void 0 ? void 0 : _global.isExemptionApproved) || false
  };
}

/**
 * @function getModuleName - get module name from ticket Id
 * @param {string} ticketId 
 * @param {string} token 
 * @returns {string}
 */

async function getModuleName(ticketId, token) {
  return await requestAPI({
    'method': 'GET',
    'hostname': 'desk.zoho.com',
    'path': `/supportapi/zd/zohodeskteam/api/v1/tickets/${ticketId}?include=secondaryContacts,departments,contacts,products,assignee,team,contract,source,skills,isRead`,
    'headers': {
      'Authorization': `Zoho-oauthtoken ${token}`
    },
    'maxRedirects': 20
  }, undefined, true);
}

/**
 * @function pushInfoToGrafana - push lint stats to grafana 
 * @param {Array<string>} cliArgument 
 */

async function pushInfoToGrafana(cliArgument) {
  var _global2;
  const data = JSON.stringify({
    service_name: requestHostDomain,
    metric_name: metricName,
    metric_type: metricType,
    metric_value: ((_global2 = global) === null || _global2 === void 0 || (_global2 = _global2.analytics) === null || _global2 === void 0 ? void 0 : _global2.totalIssues) || metricValue,
    sleep_time: sleepTime,
    labels: await constructLayoutInfo(cliArgument)
  });
  var options = {
    method: "POST",
    hostname: apiEndPoint,
    path: path,
    headers: {
      RequestHostDomain: requestHostDomain,
      Authorization: auth_token_noExpired,
      "Content-Type": type,
      'Content-Length': Buffer.byteLength(data)
    },
    maxRedirects: 20
  };
  const response = JSON.parse(await requestAPI(options, data, true));
  if ((response === null || response === void 0 ? void 0 : response.status) == 'success') {
    Logger.log(Logger.SUCCESS_TYPE, `Linter stats push to grafana`);
  }
}