"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _logger = require("./logger.js");
var _FileUtilities = _interopRequireDefault(require("./FileUtilities.js"));
var _child_process = require("child_process");
class PathUtilities {
  /**
   * @function getSonarJarPath -  check and return sonar jar path
   * @returns {string}
   */

  static getSonarJarPath() {
    const jarPath = _path.default.resolve(__dirname, "..", "core", "sonar-dependencies", "java-jar", "sonar-scanner.jar");
    if (_FileUtilities.default.checkIfFileExists(jarPath)) {
      return jarPath;
    }
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "Cannot find -  Java-Jar");
    process.exit(0);
  }

  /**
   * @function getLintReportPath - construct lint report path
   * @returns {string}
   */

  static getLintReportPath() {
    const {
      lintReportPath
    } = _FileUtilities.default.getLintConfiguration();
    return lintReportPath;
  }

  /**
   * @function resolvePath - resolve given  file path 
   * @param {string} resolveFilePath -  file path 
   * @returns {string}
   */

  static resolvePath(resolveFilePath) {
    const file_Path = _path.default.resolve(resolveFilePath);
    if (!_FileUtilities.default.checkIfFileExists(file_Path)) {
      _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "file does not exist ..");
      process.exit(0);
    }
    return file_Path;
  }

  /**
   * @function getRootGitPath -  get git root path
   * @returns {string}
   */

  static getRootGitPath() {
    const childProcess = (0, _child_process.spawnSync)("git", ["rev-parse", "--show-toplevel"], {
      shell: true
    });
    return childProcess.stdout.toString().split("\n").filter(Boolean).pop();
  }

  /**
   * @function {constructConfigPath} -  construct path of configuration file
   * @returns {string}
   */

  static constructConfigPath() {
    return _path.default.resolve(process.cwd(), "lint.config.js");
  }

  /**
   * @function filterFiles - filter javascript files. omit feature files
   * @param {Array<String>} lintFiles - linter files as Array
   * @returns {Array<String>} 
   */
}
var _default = exports.default = PathUtilities;